@@ -1,4 +1,7 @@
-use super::{file_command::FilePlaceholder, SlashCommand, SlashCommandOutput};
+use super::{
+    file_command::{build_entry_output_section, codeblock_fence_for_path},
+    SlashCommand, SlashCommandOutput,
+};
 use anyhow::Result;
 use assistant_slash_command::SlashCommandOutputSection;
 use gpui::{AppContext, Task, WeakView};
@@ -9,7 +12,7 @@ use std::{
     path::PathBuf,
     sync::{atomic::AtomicBool, Arc},
 };
-use ui::{prelude::*, ButtonLike, ElevationIndex, Icon, IconName};
+use ui::{prelude::*, IconName};
 use util::ResultExt;
 use workspace::Workspace;
 
@@ -44,7 +47,7 @@ impl SlashCommand for SearchSlashCommand {
     }
 
     fn complete_argument(
-        &self,
+        self: Arc<Self>,
         _query: String,
         _cancel: Arc<AtomicBool>,
         _workspace: Option<WeakView<Workspace>>,
@@ -125,9 +128,8 @@ impl SlashCommand for SearchSlashCommand {
                         let range_start = result.range.start.min(file_content.len());
                         let range_end = result.range.end.min(file_content.len());
 
-                        let start_line =
-                            file_content[0..range_start].matches('\n').count() as u32 + 1;
-                        let end_line = file_content[0..range_end].matches('\n').count() as u32 + 1;
+                        let start_row = file_content[0..range_start].matches('\n').count() as u32;
+                        let end_row = file_content[0..range_end].matches('\n').count() as u32;
                         let start_line_byte_offset = file_content[0..range_start]
                             .rfind('\n')
                             .map(|pos| pos + 1)
@@ -138,47 +140,30 @@ impl SlashCommand for SearchSlashCommand {
                             .unwrap_or_else(|| file_content.len());
 
                         let section_start_ix = text.len();
-                        writeln!(
-                            text,
-                            "```{}:{}-{}",
-                            result.path.display(),
-                            start_line,
-                            end_line,
-                        )
-                        .unwrap();
+                        text.push_str(&codeblock_fence_for_path(
+                            Some(&result.path),
+                            Some(start_row..end_row),
+                        ));
+
                         let mut excerpt =
                             file_content[start_line_byte_offset..end_line_byte_offset].to_string();
                         LineEnding::normalize(&mut excerpt);
                         text.push_str(&excerpt);
                         writeln!(text, "\n```\n").unwrap();
                         let section_end_ix = text.len() - 1;
-
-                        sections.push(SlashCommandOutputSection {
-                            range: section_start_ix..section_end_ix,
-                            render_placeholder: Arc::new(move |id, unfold, _| {
-                                FilePlaceholder {
-                                    id,
-                                    path: Some(full_path.clone()),
-                                    line_range: Some(start_line..end_line),
-                                    unfold,
-                                }
-                                .into_any_element()
-                            }),
-                        });
+                        sections.push(build_entry_output_section(
+                            section_start_ix..section_end_ix,
+                            Some(&full_path),
+                            false,
+                            Some(start_row + 1..end_row + 1),
+                        ));
                     }
 
                     let query = SharedString::from(query);
                     sections.push(SlashCommandOutputSection {
                         range: 0..text.len(),
-                        render_placeholder: Arc::new(move |id, unfold, _cx| {
-                            ButtonLike::new(id)
-                                .style(ButtonStyle::Filled)
-                                .layer(ElevationIndex::ElevatedSurface)
-                                .child(Icon::new(IconName::MagnifyingGlass))
-                                .child(Label::new(query.clone()))
-                                .on_click(move |_, cx| unfold(cx))
-                                .into_any_element()
-                        }),
+                        icon: IconName::MagnifyingGlass,
+                        label: query,
                     });
 
                     SlashCommandOutput {
