@@ -14,7 +14,9 @@ use language::{
 };
 use lsp::FakeLanguageServer;
 use pretty_assertions::assert_eq;
-use project::{search::SearchQuery, Project, ProjectPath, SearchResult};
+use project::{
+    search::SearchQuery, Project, ProjectPath, SearchResult, DEFAULT_COMPLETION_CONTEXT,
+};
 use rand::{
     distributions::{Alphanumeric, DistString},
     prelude::*,
@@ -303,7 +305,7 @@ impl RandomizedTest for ProjectCollaborationTest {
                                     .filter(|worktree| {
                                         let worktree = worktree.read(cx);
                                         worktree.is_visible()
-                                            && worktree.entries(false).any(|e| e.is_file())
+                                            && worktree.entries(false, 0).any(|e| e.is_file())
                                             && worktree.root_entry().map_or(false, |e| e.is_dir())
                                     })
                                     .choose(rng)
@@ -425,14 +427,14 @@ impl RandomizedTest for ProjectCollaborationTest {
                                     .filter(|worktree| {
                                         let worktree = worktree.read(cx);
                                         worktree.is_visible()
-                                            && worktree.entries(false).any(|e| e.is_file())
+                                            && worktree.entries(false, 0).any(|e| e.is_file())
                                     })
                                     .choose(rng)
                             });
                             let Some(worktree) = worktree else { continue };
                             let full_path = worktree.read_with(cx, |worktree, _| {
                                 let entry = worktree
-                                    .entries(false)
+                                    .entries(false, 0)
                                     .filter(|e| e.is_file())
                                     .choose(rng)
                                     .unwrap();
@@ -829,7 +831,7 @@ impl RandomizedTest for ProjectCollaborationTest {
                         .map_ok(|_| ())
                         .boxed(),
                     LspRequestKind::Completion => project
-                        .completions(&buffer, offset, cx)
+                        .completions(&buffer, offset, DEFAULT_COMPLETION_CONTEXT, cx)
                         .map_ok(|_| ())
                         .boxed(),
                     LspRequestKind::CodeAction => project
@@ -873,8 +875,15 @@ impl RandomizedTest for ProjectCollaborationTest {
 
                 let mut search = project.update(cx, |project, cx| {
                     project.search(
-                        SearchQuery::text(query, false, false, false, Vec::new(), Vec::new())
-                            .unwrap(),
+                        SearchQuery::text(
+                            query,
+                            false,
+                            false,
+                            false,
+                            Default::default(),
+                            Default::default(),
+                        )
+                        .unwrap(),
                         cx,
                     )
                 });
@@ -1204,8 +1213,8 @@ impl RandomizedTest for ProjectCollaborationTest {
                                         guest_project.remote_id(),
                                     );
                                     assert_eq!(
-                                        guest_snapshot.entries(false).collect::<Vec<_>>(),
-                                        host_snapshot.entries(false).collect::<Vec<_>>(),
+                                        guest_snapshot.entries(false, 0).collect::<Vec<_>>(),
+                                        host_snapshot.entries(false, 0).collect::<Vec<_>>(),
                                         "{} has different snapshot than the host for worktree {:?} ({:?}) and project {:?}",
                                         client.username,
                                         host_snapshot.abs_path(),
