@@ -1,5 +1,6 @@
 //! This module contains all actions supported by [`Editor`].
 use super::*;
+use gpui::action_as;
 use util::serde::default_true;
 
 #[derive(PartialEq, Clone, Deserialize, Default)]
@@ -125,6 +126,11 @@ pub struct ExpandExcerptsDown {
     #[serde(default)]
     pub(super) lines: u32,
 }
+#[derive(PartialEq, Clone, Deserialize, Default)]
+pub struct ShowCompletions {
+    #[serde(default)]
+    pub(super) trigger: Option<char>,
+}
 
 impl_actions!(
     editor,
@@ -147,6 +153,7 @@ impl_actions!(
         SelectToBeginningOfLine,
         SelectToEndOfLine,
         SelectUpByLines,
+        ShowCompletions,
         ToggleCodeActions,
         ToggleComments,
         UnfoldAt,
@@ -163,6 +170,7 @@ gpui::actions!(
         AddSelectionBelow,
         Backspace,
         Cancel,
+        CancelLanguageServerWork,
         ConfirmRename,
         ContextMenuFirst,
         ContextMenuLast,
@@ -273,8 +281,9 @@ gpui::actions!(
         SelectToPreviousWordStart,
         SelectToStartOfParagraph,
         SelectUp,
+        SelectPageDown,
+        SelectPageUp,
         ShowCharacterPalette,
-        ShowCompletions,
         ShowInlineCompletion,
         ShuffleLines,
         SortLinesCaseInsensitive,
@@ -284,6 +293,7 @@ gpui::actions!(
         TabPrev,
         ToggleGitBlame,
         ToggleGitBlameInline,
+        ToggleSelectionMenu,
         ToggleHunkDiff,
         ToggleInlayHints,
         ToggleLineNumbers,
@@ -298,3 +308,7 @@ gpui::actions!(
         UniqueLinesCaseSensitive,
     ]
 );
+
+action_as!(outline, ToggleOutline as Toggle);
+
+action_as!(go_to_line, ToggleGoToLine as Toggle);
