@@ -571,7 +571,11 @@ impl<V> View<V> {
         use postage::prelude::{Sink as _, Stream as _};
 
         let (tx, mut rx) = postage::mpsc::channel(1024);
-        let timeout_duration = Duration::from_millis(100);
+        let timeout_duration = if cfg!(target_os = "macos") {
+            Duration::from_millis(100)
+        } else {
+            Duration::from_secs(1)
+        };
 
         let mut cx = cx.app.borrow_mut();
         let subscriptions = (
