@@ -2,12 +2,13 @@ use std::sync::Arc;
 
 use gpui::ClickEvent;
 
-use crate::{prelude::*, Color, IconButton, IconName, IconSize};
+use crate::{prelude::*, Color, IconButton, IconButtonShape, IconName, IconSize};
 
 #[derive(IntoElement)]
 pub struct Disclosure {
     id: ElementId,
     is_open: bool,
+    selected: bool,
     on_toggle: Option<Arc<dyn Fn(&ClickEvent, &mut WindowContext) + 'static>>,
 }
 
@@ -16,6 +17,7 @@ impl Disclosure {
         Self {
             id: id.into(),
             is_open,
+            selected: false,
             on_toggle: None,
         }
     }
@@ -29,6 +31,20 @@ impl Disclosure {
     }
 }
 
+impl Selectable for Disclosure {
+    fn selected(mut self, selected: bool) -> Self {
+        self.selected = selected;
+        self
+    }
+}
+
+impl Clickable for Disclosure {
+    fn on_click(mut self, handler: impl Fn(&ClickEvent, &mut WindowContext) + 'static) -> Self {
+        self.on_toggle = Some(Arc::new(handler));
+        self
+    }
+}
+
 impl RenderOnce for Disclosure {
     fn render(self, _cx: &mut WindowContext) -> impl IntoElement {
         IconButton::new(
@@ -38,8 +54,10 @@ impl RenderOnce for Disclosure {
                 false => IconName::ChevronRight,
             },
         )
+        .shape(IconButtonShape::Square)
         .icon_color(Color::Muted)
         .icon_size(IconSize::Small)
+        .selected(self.selected)
         .when_some(self.on_toggle, move |this, on_toggle| {
             this.on_click(move |event, cx| on_toggle(event, cx))
         })
